@@ -5,7 +5,7 @@
 
  @section LICENSE
 
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -56,9 +56,9 @@ for language_code in os.listdir(locale_path):
 
         # Loop through all test strings
         for source_string in all_strings:
-            if "%s" in source_string:
+            if "%s" in source_string or "%s(" in source_string or "%d" in source_string:
                 translated_string = app.translate("", source_string)
-                if source_string.count('%') != translated_string.count('%s'):
+                if source_string.count('%') != translated_string.count('%'):
                     print('  Invalid string replacement found: %s  (source: %s)' % (translated_string, source_string))
 
         # Remove translator
