@@ -6,7 +6,7 @@
 
  @section LICENSE
 
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -59,10 +59,13 @@ class AddToTimeline(QDialog):
 
         # Get selected file
         files = self.treeFiles.timeline_model.files
-        selected_index = self.treeFiles.selected.row()
+
+        selected_index = None
+        if self.treeFiles.selected:
+            selected_index = self.treeFiles.selected.row()
 
         # Ignore if empty files
-        if not files:
+        if not files or selected_index == None:
             return
 
         # New index
@@ -85,10 +88,13 @@ class AddToTimeline(QDialog):
 
         # Get selected file
         files = self.treeFiles.timeline_model.files
-        selected_index = self.treeFiles.selected.row()
+
+        selected_index = None
+        if self.treeFiles.selected:
+            selected_index = self.treeFiles.selected.row()
 
         # Ignore if empty files
-        if not files:
+        if not files or selected_index == None:
             return
 
         # New index
@@ -121,10 +127,13 @@ class AddToTimeline(QDialog):
 
         # Get selected file
         files = self.treeFiles.timeline_model.files
-        selected_index = self.treeFiles.selected.row()
+
+        selected_index = None
+        if self.treeFiles.selected:
+            selected_index = self.treeFiles.selected.row()
 
         # Ignore if empty files
-        if not files:
+        if not files or selected_index == None:
             return
 
         # Remove item
