@@ -7,7 +7,7 @@
 
  @section LICENSE
 
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -48,6 +48,7 @@ from classes.timeline import TimelineSync
 from classes.query import File, Clip, Transition, Marker, Track
 from classes.metrics import *
 from classes.version import *
+from classes.conversion import zoomToSeconds, secondsToZoom
 from images import openshot_rc
 from windows.views.files_treeview import FilesTreeView
 from windows.views.files_listview import FilesListView
@@ -61,7 +62,7 @@ from windows.video_widget import VideoWidget
 from windows.preview_thread import PreviewParent
 
 
-class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
+class MainWindow(QMainWindow, updates.UpdateWatcher):
     """ This class contains the logic for the main window widget """
 
     # Path to ui file
@@ -83,6 +84,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
     ExportFrame = pyqtSignal(str, int, int, int)
     ExportEnded = pyqtSignal(str)
     MaxSizeChanged = pyqtSignal(object)
+    InsertKeyframe = pyqtSignal(object)
 
     # Save window settings on close
     def closeEvent(self, event):
@@ -161,6 +163,9 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
             # No backup project found
             # Load a blank project (to propagate the default settings)
             get_app().project.load("")
+            self.actionUndo.setEnabled(False)
+            self.actionRedo.setEnabled(False)
+            self.SetWindowTitle()
 
     def create_lock_file(self):
         """Create a lock file"""
@@ -206,7 +211,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
                 # Get top line of stack trace (for metrics)
                 last_log_line = last_stack_trace.split("\n")[0].strip()
 
-                # Send stacktrace for debugging (if send metrics is enalbed)
+                # Send stacktrace for debugging (if send metrics is enabled)
                 track_exception_stacktrace(last_stack_trace, "libopenshot")
 
             # Clear / normalize log line (so we can roll them up in the analytics)
@@ -233,9 +238,6 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
             log.error("Unhandled crash detected... will attempt to recover backup project: %s" % info.BACKUP_PATH)
             track_metric_error("unhandled-crash%s" % last_log_line, True)
 
-            # Recover backup file (this can't happen until after the Main Window has completely loaded)
-            QTimer.singleShot(250, self.RecoverBackup.emit)
-
             # Remove file
             self.destroy_lock_file()
 
@@ -243,9 +245,6 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
             # Normal startup, clear thumbnails
             self.clear_all_thumbnails()
 
-            # Load a blank project (to propagate the default settings)
-            get_app().project.load("")
-
         # Create lock file
         with open(lock_path, 'w') as f:
             f.write(lock_value)
@@ -431,7 +430,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         get_app().setOverrideCursor(QCursor(Qt.WaitCursor))
 
         try:
-            if os.path.exists(file_path.encode('UTF-8')):
+            if os.path.exists(file_path):
                 # Clear any previous thumbnails
                 if clear_thumbnails:
                     self.clear_all_thumbnails()
@@ -587,13 +586,14 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
     def actionImportFiles_trigger(self, event):
         app = get_app()
         _ = app._tr
-        recommended_path = app.project.current_filepath
-        if not recommended_path:
+        recommended_path = app.project.get(["import_path"])
+        if not recommended_path or not os.path.exists(recommended_path):
             recommended_path = os.path.join(info.HOME_PATH)
         files = QFileDialog.getOpenFileNames(self, _("Import File..."), recommended_path)[0]
         for file_path in files:
             self.filesTreeView.add_file(file_path)
             self.filesTreeView.refresh_view()
+            app.updates.update(["import_path"], os.path.dirname(file_path))
             log.info("Imported media file {}".format(file_path))
 
     def actionAdd_to_Timeline_trigger(self, event):
@@ -706,11 +706,10 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
 
     def actionHelpContents_trigger(self, event):
         try:
-            webbrowser.open("http://www.openshot.org/files/user-guide/?app-menu")
+            webbrowser.open("http://%s.openshot.org/files/user-guide/?app-menu" % info.website_language())
             log.info("Help Contents is open")
         except:
-            QMessageBox.information(self, "Error !",
-                                    "Unable to open the Help Contents. Please ensure the openshot-doc package is installed.")
+            QMessageBox.information(self, "Error !", "Unable to open the Help Contents. Please ensure the openshot-doc package is installed.")
             log.info("Unable to open the Help Contents")
 
     def actionAbout_trigger(self, event):
@@ -750,7 +749,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
 
     def actionDonate_trigger(self, event):
         try:
-            webbrowser.open("http://openshot.org/donate/?app-menu")
+            webbrowser.open("http://%s.openshot.org/donate/?app-menu" % info.website_language())
             log.info("Open the Donate web page with success")
         except:
             QMessageBox.information(self, "Error !", "Unable to open the Donate web page")
@@ -758,7 +757,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
 
     def actionUpdate_trigger(self, event):
         try:
-            webbrowser.open("http://openshot.org/download/?app-toolbar")
+            webbrowser.open("http://%s.openshot.org/download/?app-toolbar" % info.website_language())
             log.info("Open the Download web page with success")
         except:
             QMessageBox.information(self, "Error !", "Unable to open the Download web page")
@@ -886,7 +885,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         # Get # of tracks
         track_number = len(get_app().project.get(["layers"]))
 
-        # Look for existing Marker
+        # Create new track above existing layer(s)
         track = Track()
         track.data = {"number": track_number, "y": 0, "label": "", "lock": False}
         track.save()
@@ -902,22 +901,34 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         existing_track = Track.get(id=selected_layer_id)
         selected_layer_number = int(existing_track.data["number"])
 
-        # Create new track
-        track = Track()
-        track.data = {"number": max_track_number, "y": 0, "label": "", "lock": False}
-        track.save()
+        # log.info("Adding track above #{} (id {})".format(selected_layer_number, selected_layer_id))
 
-        # Loop through all clips on higher layers, and move to new layer (in reverse order)
-        for existing_layer in list(reversed(range(selected_layer_number + 1, max_track_number))):
-            existing_track.data["label"] = ""
+        # Loop through tracks above insert point (in descending order), renumbering layers
+        for existing_layer in list(reversed(range(selected_layer_number+1, max_track_number))):
+            existing_track = Track.get(number=existing_layer)
+            # log.info("Renumbering track id {} from {} to {}".format(existing_track.data["id"], existing_layer, existing_layer+1))
+            existing_track.data["number"] = existing_layer + 1
             existing_track.save()
 
+            # Loop through clips and transitions for track, moving up to new layer
             for clip in Clip.filter(layer=existing_layer):
+                # log.info("Moving clip id {} from layer {} to {}".format(clip.data["id"], int(clip.data["layer"]), int(clip.data["layer"])+1))
                 clip.data["layer"] = int(clip.data["layer"]) + 1
                 clip.save()
 
+            for trans in Transition.filter(layer=existing_layer):
+                # log.info("Moving transition id {} from layer {} to {}".format(trans.data["id"], int(trans.data["layer"]), int(trans.data["layer"])+1))
+                trans.data["layer"] = int(trans.data["layer"]) + 1
+                trans.save()
+
+        # Create new track at vacated layer
+        track = Track()
+        track.data = {"number": selected_layer_number+1, "y": 0, "label": "", "lock": False}
+        track.save()
+        # log.info("Created new track id {} at layer number {}".format(track.data["id"], track.data["number"]))
+
     def actionAddTrackBelow_trigger(self, event):
-        log.info("actionAddTrackAbove_trigger")
+        log.info("actionAddTrackBelow_trigger")
 
         # Get # of tracks
         max_track_number = len(get_app().project.get(["layers"]))
@@ -927,20 +938,32 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         existing_track = Track.get(id=selected_layer_id)
         selected_layer_number = int(existing_track.data["number"])
 
-        # Create new track
-        track = Track()
-        track.data = {"number": max_track_number, "y": 0, "label": "", "lock": False}
-        track.save()
+        # log.info("Adding track below #{} (id {})".format(selected_layer_number, selected_layer_id))
 
-        # Loop through all clips on higher layers, and move to new layer (in reverse order)
+        # Loop through tracks from insert point up (in descending order), renumbering layers
         for existing_layer in list(reversed(range(selected_layer_number, max_track_number))):
-            existing_track.data["label"] = ""
+            existing_track = Track.get(number=existing_layer)
+            # log.info("Renumbering track id {} from {} to {}".format(existing_track.data["id"], existing_layer, existing_layer+1))
+            existing_track.data["number"] = existing_layer + 1
             existing_track.save()
 
+            # Loop through clips and transitions for track, moving up to new layer
             for clip in Clip.filter(layer=existing_layer):
+                # log.info("Moving clip id {} from layer {} to {}".format(clip.data["id"], int(clip.data["layer"]), int(clip.data["layer"])+1))
                 clip.data["layer"] = int(clip.data["layer"]) + 1
                 clip.save()
 
+            for trans in Transition.filter(layer=existing_layer):
+                # log.info("Moving transition id {} from layer {} to {}".format(trans.data["id"], int(trans.data["layer"]), int(trans.data["layer"])+1))
+                trans.data["layer"] = int(trans.data["layer"]) + 1
+                trans.save()
+
+        # Create new track at vacated layer
+        track = Track()
+        track.data = {"number": selected_layer_number, "y": 0, "label": "", "lock": False}
+        track.save()
+        # log.info("Created new track id {} at layer number {}".format(track.data["id"], track.data["number"]))
+
     def actionArrowTool_trigger(self, event):
         log.info("actionArrowTool_trigger")
 
@@ -969,7 +992,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         fps_float = float(fps["num"]) / float(fps["den"])
 
         # Calculate position in seconds
-        position = player.Position() / fps_float
+        position = (player.Position() - 1) / fps_float
 
         # Look for existing Marker
         marker = Marker()
@@ -982,7 +1005,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         # Calculate current position (in seconds)
         fps = get_app().project.get(["fps"])
         fps_float = float(fps["num"]) / float(fps["den"])
-        current_position = self.preview_thread.current_frame / fps_float
+        current_position = (self.preview_thread.current_frame - 1) / fps_float
         all_marker_positions = []
 
         # Get list of marker and important positions (like selected clip bounds)
@@ -1035,7 +1058,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         # Calculate current position (in seconds)
         fps = get_app().project.get(["fps"])
         fps_float = float(fps["num"]) / float(fps["den"])
-        current_position = self.preview_thread.current_frame / fps_float
+        current_position = (self.preview_thread.current_frame - 1) / fps_float
         all_marker_positions = []
 
         # Get list of marker and important positions (like selected clip bounds)
@@ -1119,7 +1142,7 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         # Get framerate
         fps = get_app().project.get(["fps"])
         fps_float = float(fps["num"]) / float(fps["den"])
-        playhead_position = float(self.preview_thread.current_frame) / fps_float
+        playhead_position = float(self.preview_thread.current_frame - 1) / fps_float
 
         # Basic shortcuts i.e just a letter
         if key.matches(self.getShortcutByName("seekPreviousFrame")) == QKeySequence.ExactMatch:
@@ -1231,6 +1254,16 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
             self.actionJumpEnd.trigger()
         elif key.matches(self.getShortcutByName("actionProperties")) == QKeySequence.ExactMatch:
             self.actionProperties.trigger()
+        elif key.matches(self.getShortcutByName("actionTransform")) == QKeySequence.ExactMatch:
+            if not self.is_transforming and self.selected_clips:
+                self.TransformSignal.emit(self.selected_clips[0])
+            else:
+                self.TransformSignal.emit("")
+
+        elif key.matches(self.getShortcutByName("actionInsertKeyframe")) == QKeySequence.ExactMatch:
+            print("actionInsertKeyframe")
+            if self.selected_clips or self.selected_transitions:
+                self.InsertKeyframe.emit(event)
 
         # Timeline keyboard shortcuts
         elif key.matches(self.getShortcutByName("sliceAllKeepBothSides")) == QKeySequence.ExactMatch:
@@ -1424,18 +1457,22 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         # Remove track
         selected_track.delete()
 
-        # Loop through all tracks, and renumber (to keep thing in numerical order)
+        # Loop through all layers above, and renumber elements (to keep thing in numerical order)
         for existing_layer in list(range(selected_track_number + 1, max_track_number)):
-            # Update existing layer #
+            # Update existing layer number
             track = Track.get(number=existing_layer)
             track.data["number"] = existing_layer - 1
-            track.data["label"] = ""
             track.save()
 
             for clip in Clip.filter(layer=existing_layer):
                 clip.data["layer"] = int(clip.data["layer"]) - 1
                 clip.save()
 
+            for trans in Transition.filter(layer=existing_layer):
+                trans.data["layer"] = int(trans.data["layer"]) - 1
+                trans.save()
+
+
         # Clear selected track
         self.selected_tracks = []
 
@@ -1717,23 +1754,32 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         if not profile:
             profile = get_app().project.get(["profile"])
 
+        # Determine if the project needs saving (has any unsaved changes)
+        save_indicator = ""
+        if get_app().project.needs_save():
+            save_indicator = "*"
+            self.actionSave.setEnabled(True)
+        else:
+            self.actionSave.setEnabled(False)
+
         # Is this a saved project?
         if not get_app().project.current_filepath:
             # Not saved yet
-            self.setWindowTitle("%s [%s] - %s" % (_("Untitled Project"), profile, "OpenShot Video Editor"))
+            self.setWindowTitle("%s %s [%s] - %s" % (save_indicator, _("Untitled Project"), profile, "OpenShot Video Editor"))
         else:
             # Yes, project is saved
             # Get just the filename
             parent_path, filename = os.path.split(get_app().project.current_filepath)
             filename, ext = os.path.splitext(filename)
             filename = filename.replace("_", " ").replace("-", " ").capitalize()
-            self.setWindowTitle("%s [%s] - %s" % (filename, profile, "OpenShot Video Editor"))
+            self.setWindowTitle("%s %s [%s] - %s" % (save_indicator, filename, profile, "OpenShot Video Editor"))
 
     # Update undo and redo buttons enabled/disabled to available changes
     def updateStatusChanged(self, undo_status, redo_status):
         log.info('updateStatusChanged')
         self.actionUndo.setEnabled(undo_status)
         self.actionRedo.setEnabled(redo_status)
+        self.SetWindowTitle()
 
     # Add to the selected items
     def addSelection(self, item_id, item_type, clear_existing=False):
@@ -1946,17 +1992,19 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         self.timelineToolbar.addSeparator()
 
         # Get project's initial zoom value
-        initial_scale = get_app().project.get(["scale"]) or 20
+        initial_scale = get_app().project.get(["scale"]) or 16
+        # Round non-exponential scale down to next lowest power of 2
+        initial_zoom = secondsToZoom(initial_scale)
 
         # Setup Zoom slider
         self.sliderZoom = QSlider(Qt.Horizontal, self)
-        self.sliderZoom.setPageStep(2)
-        self.sliderZoom.setRange(1, 800)
-        self.sliderZoom.setValue(initial_scale)
+        self.sliderZoom.setPageStep(1)
+        self.sliderZoom.setRange(0, 30)
+        self.sliderZoom.setValue(initial_zoom)
         self.sliderZoom.setInvertedControls(True)
         self.sliderZoom.resize(100, 16)
 
-        self.zoomScaleLabel = QLabel(_("{} seconds").format(self.sliderZoom.value()))
+        self.zoomScaleLabel = QLabel( _("{} seconds").format(zoomToSeconds(self.sliderZoom.value())) )
 
         # add zoom widgets
         self.timelineToolbar.addAction(self.actionTimelineZoomIn)
@@ -2102,6 +2150,13 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         except:
             pass
 
+    def transformTriggered(self, clip_id):
+        """Handle transform signal (to keep track of whether a transform is happening or not)"""
+        if clip_id and clip_id in self.selected_clips:
+            self.is_transforming = True
+        else:
+            self.is_transforming = False
+
 
     def __init__(self, mode=None):
 
@@ -2154,6 +2209,8 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         get_current_Version()
 
         # Connect signals
+        self.is_transforming = False
+        self.TransformSignal.connect(self.transformTriggered)
         if not self.mode == "unittest":
             self.RecoverBackup.connect(self.recover_backup)
 
@@ -2164,9 +2221,6 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         self.timeline = TimelineWebView(self)
         self.frameWeb.layout().addWidget(self.timeline)
 
-        # Set Window title
-        self.SetWindowTitle()
-
         # Setup files tree
         if s.get("file_view") == "details":
             self.filesTreeView = FilesTreeView(self)
@@ -2239,6 +2293,12 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         if s.get("enable-auto-save"):
             self.auto_save_timer.start()
 
+        # Set hardware decode environment variable
+        if s.get("hardware_decode"):
+            os.environ['OS2_DECODE_HW'] = "1"
+        else:
+            os.environ['OS2_DECODE_HW'] = "0"
+
         # Create lock file
         self.create_lock_file()
 
@@ -2266,4 +2326,4 @@ class MainWindow(QMainWindow, updates.UpdateWatcher, updates.UpdateInterface):
         QTimer.singleShot(100, self.refreshFrameSignal.emit)
 
         # Main window is initialized
-        self.initialized = True
\ No newline at end of file
+        self.initialized = True
