@@ -6,7 +6,7 @@
 
  @section LICENSE
 
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -278,6 +278,14 @@ class Preferences(QDialog):
                 # Stop autosave timer
                 get_app().window.auto_save_timer.stop()
 
+        elif param["setting"] == "hardware_decode":
+            if (state == Qt.Checked):
+                # Enable hardware decode environment variable
+                os.environ['OS2_DECODE_HW'] = "1"
+            else:
+                # Disable hardware decode environment variable
+                os.environ['OS2_DECODE_HW'] = "0"
+
         # Check for restart
         self.check_for_restart(param)
 
