@@ -6,7 +6,7 @@
  
  @section LICENSE
  
- Copyright (c) 2008-2016 OpenShot Studios, LLC
+ Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
@@ -465,8 +465,10 @@ class TitleEditor(QDialog):
             # ignoring font-weight, as not sure what it represents in Qt.
             fs = self.find_in_list(ar, "font-style:")
             ff = self.find_in_list(ar, "font-family:")
-            ar[fs] = "font-style:" + self.font_style
-            ar[ff] = "font-family:" + self.font_family
+            if fs:
+                ar[fs] = "font-style:" + self.font_style
+            if ff:
+                ar[ff] = "font-family:" + self.font_family
             # rejoin the modified parts
             t = ";"
             self.title_style_string = t.join(ar)
@@ -486,8 +488,10 @@ class TitleEditor(QDialog):
             # ignoring font-weight, as not sure what it represents in Qt.
             fs = self.find_in_list(ar, "font-style:")
             ff = self.find_in_list(ar, "font-family:")
-            ar[fs] = "font-style:" + self.font_style
-            ar[ff] = "font-family:" + self.font_family
+            if fs:
+                ar[fs] = "font-style:" + self.font_style
+            if ff:
+                ar[ff] = "font-family:" + self.font_family
             # rejoin the modified parts
             t = ";"
             self.title_style_string = t.join(ar)
@@ -514,7 +518,7 @@ class TitleEditor(QDialog):
             else:
                 ar[opacity] = "opacity:" + str(alpha)
 
-            # rejoin the modifed parts
+            # rejoin the modified parts
             t = ";"
             self.bg_style_string = t.join(ar)
             # set the node in the xml doc
